Patio, Lawn, & Garden Furniture & Décor for Sale Online | Christmas Central
Author: Christmas Central
Description: Christmas Central carries a variety of quality patio furniture, lawn ornaments, and garden décor. Browse items on sale and order today!
Keywords: patio, lawn, garden, artificial trees, artificial shrubs, bird feeder, bird house, cupolas, door mat, finial, fire pit, fire dome, fireplace, flag, fountain, garden accessories, weathervanes, mailbox cover, outdoor cooking, outdoor dining, patio cushion, patio décor, patio lights, patio umbrella, planter, pool, spa, rain chain, statue, garden statue, torches, wall décor, windchime

ARTIFICIAL CHRISTMAS TREES

### CHRISTMAS TREE TYPES

- Traditional Christmas Trees
- Pre Lit Christmas Trees
- Unlit Christmas Trees
- Alpine Trees
- Colorful Christmas Trees
- Fiber Optic Christmas Trees
- Frosted and Flocked Christmas Trees
- Giant Commercial Christmas Trees

- Potted Christmas Trees
- Stake Christmas Trees
- Topiaries
- Twig Trees
- Upside Down Christmas Trees
- Wall Christmas Trees
- Yard Art Trees
- Other Christmas Trees

### TREE ACCESSORIES

- Christmas Tree Stands
- Christmas Tree Toppers
- Christmas Tree Skirts
- Christmas Tree Storage
- Electrical Cords
- Other Christmas Tree Accessories

### TREE DECORATIONS

- Ornaments
- Christmas Lights
- Garland
- Sprays, Branches & Picks
- Hooks

LIGHTS

### CHRISTMAS LIGHT TYPES

- 24 Volt Connect Lights
- Battery Operated Lights
- Berry Lights
- Bubble Lights
- C5 Christmas Lights
- C6 Christmas Lights
- C7 Christmas Lights
- C9 Christmas Lights
- Candle Lamps
- Candles
- Commercial Light Spools

- Edison Lights
- Electrical Cords
- Flood Lights
- Garland
- Globe Lights
- Icicle Lights
- Light Accessories
- Linear Lights
- Luminaries
- Mini Lights
- Net Lights

- Night Lights
- Novelty Lights
- Other Christmas Lights
- Replacements
- Rice and Micro Lights
- Rope Lights
- Snowfall
- Sphere Balls
- Trunk Lights
- Wide Angle Lights

### LIGHT ACCESSORIES

- Light Keeper
- Light Storage
- Electrical Cords
- Timers

### WINDOW AND YARD

- Yard Art
- Window Decorations

ORNAMENTS

### SHATTERPROOF

- SHATTERPROOF BALLS
- Multi Shatteproof Balls
- Black Shatterproof Balls
- Blue Shatterproof Balls
- Brown Shatterproof Balls
- Gold Shatterproof Balls
- Gray Shatterproof Balls
- Green Shatterproof Balls
- Orange Shatterproof Balls
- Pink Shatterproof Balls
- Purple Shatterproof Balls
- Red Shatterproof Balls
- Silver Shatterproof Balls
- White Shatterproof Balls
- Yellow Shatterproof Balls
- Shatterproof Candy Canes
- Shatterproof Decorations
- Shatterproof Finials
- Shatterproof Sets
- Shatterproof Snowflakes

### ORNAMENT STYLES

- 12 Days Of Christmas
- Angels and Cherubs
- Animals
- Armed Services
- Baby
- Baldwin Brass
- Bands and Singers
- Beach and Tropical
- Bells
- Boats
- Box Sets
- Candies and Cookies
- Cars Trains and Planes
- Cartoon Characters
- Casino
- Christopher Radko
- Coca Cola
- Country
- Dance and Ballerina
- David Strand

- Diamonds
- Diva
- Fairies and Elves
- Family and Friends
- Finials
- Fontanini
- Food and Beverage
- Garden and Floral
- Gay and Lesbian Pride
- Gingerbread
- Glass
- Glass Ball Ornaments
- Glitter
- Gnomes
- Hearts
- Heirloom Collection
- Humor
- Icicles
- Inge Glas

- Inspirational
- Irish Themed
- Jingle Buddies
- Krinkles
- Mark Roberts Fairies
- Mercury Glass
- Miniatures
- Movies and TV
- Multi Colored
- Musical Instruments
- Nativity and Religious
- Neqwa
- Nutcrackers
- Occupations
- Old World Christmas
- Other
- Outdoors
- Personalized
- Photo Frames
- Polonaise

- Santa Claus
- Shatterproof and Unbreakable
- Shoes and Handbags
- S'mores
- Snowflakes
- Snowmen
- Sport Teams Ornaments
- Sports
- Star Wars
- Stars
- Travel
- Trees
- TV and Movies
- Victorian
- Wedding And Anniversary
- Western
- Woodland
- Wreaths

WREATHS & GARLAND

### WREATHS

- Traditional Pine Wreaths
- Pre Lit Wreaths
- Unlit Wreaths
- Advent
- Battery Operated Wreaths
- Berry Wreaths
- Colored Wreaths
- Designer Wreaths
- Feather Wreaths
- Frosted & Flocked Wreaths
- Ice Wreaths
- Poinsettia Wreaths
- Shatterproof Ball Wreaths
- Sport Teams Wreaths
- Wreath Accessories

### GARLAND

- Traditional Pine Garland
- Pre Lit Garland
- Unlit Garland
- Beaded Garland
- Berry Garland
- Classic Tinsel Garland
- Designer Colored Garland
- Frosted and Flocked Garlands
- Garland Accessories
- Novelty Garland
- Pre-Decorated Garland

### DECORATIVE GARLAND

- Swags
- Teardrops
- Branches
- Picks
- Sprays

### ACCESSORIES

- Storage
- Lights
- Ornaments
- Hooks

CHRISTMAS DECORATIONS

### CHRISTMAS DECORATIONS

- Advent Calendars
- Artificial Snow
- Bells
- Bows and Gift Boxes
- Candles and Holders
- Christmas Costumes
- Christmas Jewelry
- Christmas Villages
- Commercial Decorations
- Decoration Storage
- Decorative Table Top Pieces
- Gift Baskets
- Nativity Pieces
- Novelty Items

- Nutcrackers
- Plush Figures
- Ribbon
- Santa Claus Figures
- Santa Hats
- Serving Pieces
- Signs and Plaques
- Snow Globes
- Stocking Holders
- Stockings
- Trains
- Window Decorations
- Yard Art

### GARLAND

- Traditional Pine Garland
- Pre Lit Garland
- Unlit Garland
- Beaded Garland
- Berry Garland
- Classic Tinsel Garland
- Designer Colored Garland
- Frosted and Flocked Garlands
- Garland Accessories
- Novelty Garland
- Pre-Decorated Garland

### LIGHTS

### ORNAMENTS

### TREES

POOL & SPA

### CHEMICALS

- Algaecides
- Chlorine and Bromine
- Eco-Friendly
- Phosphate Remover
- Shock
- Spa Chemicals
- Stain Removers and Cleaners
- Testing
- Water Balancers
- Water Clarifiers

### CLEANING

- Automatic Pool Cleaners
- Hoses
- Leaf Rakes and Skimmers
- Maintenance Kits and Accessories
- Poles
- Pool Brushes
- Repair and Replacement Parts
- Vacuums

### COVERS

- Solar Cover Reels
- Solar Covers

### EQUIPMENT

- Accessories
- Filters and Filter Supplies
- Pool Fountains
- Pool Lights
- Pumps and Motors
- Safety
- Systems
- Thermometers

### RECREATION

- Accessories
- Air Pumps
- Floats and Loungers
- Fun Inflatables
- Games and Toys
- Goggles and Snorkels
- Kids and Instruction

HOME DECOR

### HOME DECOR

- Afghans and Throws
- Artificial Trees Shrubs and Plants
- Ball Ornaments
- Baskets
- Bathroom Accessories
- Bird Cages
- Bookends
- Candle Holders and Accessories
- Candles
- Childrens Accents
- Clocks
- Cushions & Pillows
- Decorative Boxes
- Decorative Fans
- Decorative Figures
- Decorative Fruits and Vegetables
- Decorative Pillows

- Decorative Plates and Bowls
- Decorative Table Accents
- Dog Beds
- Door Accessories
- Electrical Cords
- Finials
- Fireplaces and Accessory
- Floral
- Furniture
- Globes
- Kitchen & Bar
- Lighting
- Linens
- Mirrors
- Nautical
- Office Decor
- Photo Frames

- Planters
- Plaques and Signs
- Racks Stands Hooks
- Religious Decor
- Ribbon
- Rugs
- Sports Teams Home Decor
- Statuary
- Stuffed Animals and Figures
- Table Cloths
- Table Runners and Placemats
- Toys and Games
- Trays and Platters
- Vases Bottles and Jars
- Wall Decor
- Wine Themed Decor

### DECORATIVE LIGHTING

- Mini Lights
- Wide Angle Lights
- Rope Lights
- Candles
- Candle Lamps
- Battery Operated Lights
- Luminaries
- Sphere Balls
- Timers

OUTDOOR LIVING

### OUTDOOR LIVING

- Artificial Trees and Shrubs
- Bird Baths
- Bird Feeders and Houses
- Cupolas
- Door Mats
- Finials
- Fire Pits and Domes
- Fireplaces
- Flags
- Fountains

- Games & Toys
- Garden Accesories
- Garden Stakes
- Garden Weathervanes
- Gazing Balls
- Mailbox Covers
- Outdoor Cooking and Eating
- Outdoor Rugs
- Patio Cushions
- Patio Decor

- Patio Furniture
- Patio Lights
- Patio Umbrellas
- Planters
- Pool and Spa
- Rain Chains
- Statuary
- Torches
- Wall Decor
- Weathervanes
- Windchimes

### DECORATIVE LIGHTING

- Mini Lights
- Wide Angle Lights
- Rope Lights
- Candles
- Candle Lamps
- M5 and C3 Lights
- Battery Operated Lights
- Luminaries
- Sphere Balls
- Timers

MORE HOLIDAYS

### HALLOWEEN

- Costumes
- Decorations
- Lights
- Trees
- Pumpkins
- Witches
- Skulls
- Spiders
- Ghosts
- Bats
- Partyware
- Wreaths
- Garlands

### THANKSGIVING

- Harvest
- Turkeys
- Pilgrims
- Native Americans
- Wreaths
- Garland
- Centerpieces
- Partyware

### OTHER HOLIDAYS

- Hanukkah Decorations
- New Year's
- Valentines Day
- Mardi Gras
- St. Patrick's Day
- Easter
- 4th of July
- Birthday
- New Baby
- Wedding and Anniversary

SALE
Patio Lawn and Garden

- Artificial Trees and Shrubs
- Bird Baths
- Bird Feeders and Houses
- Cupolas
- Door Accessories
- Door Mats
- Finials
- Fire Pits and Domes
- Fireplaces
- Flags
- Fountains
- Games and Toys
- Garden Accessories
- Garden Stakes
- Garden Weathervanes
- Gazebos and Canopies
- Gazing Balls
- Mailbox Covers
- Outdoor Cooking and Eating
- Outdoor Rugs
- Patio Cushions
- Patio Decor
- Patio Furniture
- Patio Lights
- Patio Umbrellas
- Planters
- Pool and Spa
- Rain Chains
- Sport Teams Outdoor Decor
- Statuary
- Torches
- Wall Decor
- Weathervanes
- Windchimes

Search Within Category
Artificial Christmas Trees
Pool and Spa
Christmas Lights
More...
Christmas Ornaments
Christmas Decorations
Home Decor and Furniture
More...
Patio Lawn and Garden
More...
Other Holidays and Occasions
More...
Brand
More...
Features
More...
Color
More...
Collection
More...
Light Type
Bulb Type
More...
Light Count
More...
Light Color
More...
Wire Color
More...
Spacing
More...
Tree Profile
Needle Type
Length
More...
Material
More...
Subject
More...
Everything Else
Sports Merchandise
More...

# Patio Lawn and Garden

# 9237 results in Patio Lawn and Garden

Sort By:

- Page
  of 231
- >
- >>

9' Crank Tilt Patio Market Umbrella - Champagne: Black
$224.99 $174.99You save $50.00 (22%)
9' Crank Tilt Patio Market Umbrella - Champagne: Walnut
$224.99 $174.99You save $50.00 (22%)
9' Crank Tilt Patio Market Umbrella - Champagne: Stone Green
$224.99 $174.99You save $50.00 (22%)
9' Crank Tilt Patio Market Umbrella - Champagne: Taupe
$224.99 $174.99You save $50.00 (22%)
9' Crank Tilt Patio Market Umbrella - Champagne: Champagne Linen
$224.99 $174.99You save $50.00 (22%)
9' Crank Tilt Patio Market Umbrella - Black: Black Forest Green
$224.99 $174.99You save $50.00 (22%)
16" Recycled Earth-Friendly Outdoor Square Garden Flower Planter - White
$229.99 $190.99You save $39.00 (17%)
16" Recycled Earth-Friendly Outdoor Square Garden Flower Planter - Green
$229.99 $190.99You save $39.00 (17%)
16" Recycled Earth-Friendly Outdoor Square Garden Flower Planter - Sand Brown
$229.99 $190.99You save $39.00 (17%)
16" Recycled Earth-Friendly Outdoor Square Garden Flower Planter - Teak Brown
$229.99 $190.99You save $39.00 (17%)
16" Recycled Earth-Friendly Outdoor Square Garden Flower Planter - Black
$229.99 $190.99You save $39.00 (17%)
16" Recycled Earth-Friendly Outdoor Square Garden Flower Planter - Mahogany
$229.99 $190.99You save $39.00 (17%)
24" Handcrafted "Apollo" Pure Polished Copper Cupola Finial
$365.99 $280.99You save $85.00 (23%)
30" Hand-Hammered Medium Copper Fire Pit with Scroll Feet
$649.99 $499.99You save $150.00 (23%)
60" Signature Series Forest Green Fleck Coated Aluminum Outdoor Garden Wind Chimes
$169.99 $129.99You save $40.00 (24%)
5' Cascading Concrete Stacked Slate Square Outdoor Garden Water Fountain
$2,499.99 $1,499.99You save $1,000.00 (40%)
7' Concrete French Quarter 4-Tier Outdoor Garden Water Fountain
$2,999.99 $1,999.99You save $1,000.00 (33%)
8' Calypso Cast Stone Concrete 4-Tier Outdoor Garden Water Fountain
$3,799.99 $2,299.99You save $1,500.00 (39%)
Pack of 2 Old World Scroll Design Cast Stone Concrete Outdoor Garden Urn Planters
$1,499.99 $1,199.99You save $300.00 (20%)
Pack of 2 Ornate Ram's Head Cast Stone Concrete Outdoor Garden Urn Planters
$1,499.99 $1,199.99You save $300.00 (20%)
7.5' Half Canopy Patio Market Umbrella: Blue - Olefin
$264.99 $224.99You save $40.00 (15%)
7.5' Half Canopy Patio Market Umbrella: Chocolate - Sunbrella
$364.99 $304.99You save $60.00 (16%)
FULLY FUNCTIONAL FAIRYTALE INSPIRED OUTDOOR BIRDHOUSE
$101.99 $79.99You save $22.00 (22%)
FULLY FUNCTIONAL ENGLISH COTTAGE OUTDOOR BIRDHOUSE
$80.99 $62.99You save $18.00 (22%)
13" LED Lighted Blue Fairy Outdoor Water Fountain Garden Figure
$24.99
14" LED LIGHTED GREEN FAIRY INDOOR WATER FOUNTAIN GARDEN FIGURE
$24.99
3-Tier Brown Hanging Outdoor Patio Garden Planters 57"
$129.99 $79.99You save $50.00 (38%)
24" Handcrafted "Demeter" Pure Polished Copper Cupola Finial
$341.99 $262.99You save $79.00 (23%)
9' Hunter Green Wooden Outdoor Patio Umbrella
$92.99 $76.99You save $16.00 (17%)
19" Carillon Moonbeam Hand-Tuned Triple Seal Diamond Line Wind Chime
$39.99 $34.99You save $5.00 (13%)
23" Carillon Choir Hand-Tuned Triple Seal Elm Diamond Line Wind Chime
$44.99 $39.99You save $5.00 (11%)
17" Carillon Soprano Hand-Tuned Triple Seal Diamond Line Wind Chime
$34.99 $29.99You save $5.00 (14%)
20" Carillon "Wind" Hand-Tuned Triple Sealed Elm Wood Diamond Line Wind Chime
$64.99 $54.99You save $10.00 (15%)
20" Carillon Starlight Hand-Tuned Triple Seal Diamond Line Wind Chime
$84.99 $74.99You save $10.00 (12%)
20" Carillon Whisper Hand-Tuned Triple Seal Diamond Line Wind Chime
$44.99 $39.99You save $5.00 (11%)
26" Carillon Melody Hand-Tuned Triple Sealed Elm Wood Diamond Line Wind Chime
$64.99 $54.99You save $10.00 (15%)
26" Carillon Angelic Hand-Tuned Triple Sealed Elm Wood Diamond Line Wind Chime
$64.99 $54.99You save $10.00 (15%)
23" Carillon Sonoma Hand-Tuned Triple Sealed Elm Wood Diamond Line Wind Chime
$54.99 $44.99You save $10.00 (18%)
34" Carillon Nightfall Hand-Tuned Triple Sealed Elm Wood Diamond Line Wind Chime
$104.99 $89.99You save $15.00 (14%)
34" Carillon Tenor Hand-Tuned Triple Sealed Elm Wood Diamond Line Wind Chime
$94.99 $79.99You save $15.00 (16%)

- Page
  of 231
- >
- >>

Christmas Central’s seasonal shop offers an amazing assortment of patio furniture, lawn ornaments, and garden décor online. With shipping perks and frequent sales, we’re your ideal source for outdoor decorating. Enhance your patio, yard, or sunroom with incredible canopy furniture, solar powered umbrellas, and weather resistant resin wicker patio sets. We also carry an exciting mixture of artificial trees & shrubs, cupolas, flags, fountains, and bird baths. Christmas Central has everything you need to make the outdoors your own special paradise.
#1 Fastest Growing Company In Western NY.
Top 5,000 Fastest Growing Private Companies In The U.S. For Three Straight Years

#### MY ACCOUNT

- Sign In/Register
- My Shopping Cart
- Track an order
- Gift Registry
- Wishlist

#### POLICIES

- Return Policy
- Shipping Policy

#### CONTACT US

1-800-433-0038

#### Christmas Central Charities

#### INFO

- About Us
- Affiliate Program
- Brand Info
- Christmas Light Info
- Christmas Tree Info
- Christmas Ornament Info
- Christmas Wreath Info
- Christmas Garland Info
- Common Questions
- Decorating Hints/Tips
- Decorating Themes
- How-To Videos

Enter Email To Receive EXCLUSIVE Weekly Offers!

Terms & Conditions | Privacy Policy
Copyright © 2015 Gordon Companies, Inc. All Rights Reserved.
"Christmas Central," "christmascentral.com," and the Christmas Central logo are trademarks of Gordon Companies, Inc., Cheektowaga, NY.
Christmas Central is Upfront